[−][src]Type Definition lpc55_pac::syscon::presetctrl1::SCT_RST_R
type SCT_RST_R = R<bool, SCT_RST_A>;
Reader of field SCT_RST
Implementations
impl SCT_RST_R[src]
pub fn variant(&self) -> SCT_RST_A[src]
Get enumerated values variant
pub fn is_released(&self) -> bool[src]
Checks if the value of the field is RELEASED
pub fn is_asserted(&self) -> bool[src]
Checks if the value of the field is ASSERTED